@@ -35,7 +35,7 @@ namespace lms::db
 {
     namespace
     {
-        static constexpr Version LMS_DATABASE_VERSION{ 62 };
+        static constexpr Version LMS_DATABASE_VERSION{ 64 };
     }
 
     VersionInfo::VersionInfo()
@@ -664,6 +664,56 @@ SELECT
         session.getDboSession()->execute("UPDATE scan_settings SET scan_version = scan_version + 1");
     }
 
+    void migrateFromV62(Session& session)
+    {
+        // Add a new column comment
+        session.getDboSession()->execute("ALTER TABLE track ADD comment TEXT NOT NULL DEFAULT ''");
+
+        // Just increment the scan version of the settings to make the next scheduled scan rescan everything
+        session.getDboSession()->execute("UPDATE scan_settings SET scan_version = scan_version + 1");
+    }
+
+    void migrateFromV63(Session& session)
+    {
+        // Add a rated entities
+
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "rated_artist" (
+  "id" integer primary key autoincrement,
+  "version" integer not null,
+  "rating" integer not null,
+  "last_updated" text,
+  "artist_id" bigint,
+  "user_id" bigint,
+  constraint "fk_rated_artist_artist" foreign key ("artist_id") references "artist" ("id") on delete cascade deferrable initially deferred,
+  constraint "fk_rated_artist_user" foreign key ("user_id") references "user" ("id") on delete cascade deferrable initially deferred
+))");
+
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "rated_release" (
+  "id" integer primary key autoincrement,
+  "version" integer not null,
+  "rating" integer not null,
+  "last_updated" text,
+  "release_id" bigint,
+  "user_id" bigint,
+  constraint "fk_rated_release_release" foreign key ("release_id") references "release" ("id") on delete cascade deferrable initially deferred,
+  constraint "fk_rated_release_user" foreign key ("user_id") references "user" ("id") on delete cascade deferrable initially deferred
+))");
+
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "rated_track" (
+  "id" integer primary key autoincrement,
+  "version" integer not null,
+  "rating" bigint not null,
+  "last_updated" text,
+  "track_id" bigint,
+  "user_id" bigint,
+  constraint "fk_rated_track_track" foreign key ("track_id") references "track" ("id") on delete cascade deferrable initially deferred,
+  constraint "fk_rated_track_user" foreign key ("user_id") references "user" ("id") on delete cascade deferrable initially deferred
+))");
+
+        // Drop badly named index, will be recreated
+        session.getDboSession()->execute("DROP INDEX IF EXISTS listen_user_backend_date_time");
+    }
+
     bool doDbMigration(Session& session)
     {
         static const std::string outdatedMsg{ "Outdated database, please rebuild it (delete the .db file and restart)" };
@@ -702,6 +752,8 @@ SELECT
             { 59, migrateFromV59 },
             { 60, migrateFromV60 },
             { 61, migrateFromV61 },
+            { 62, migrateFromV62 },
+            { 63, migrateFromV63 },
         };
 
         bool migrationPerformed{};
